from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Microchip_SAML = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ATSAML21E15B-AUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21E15B-AUT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21E15B-AUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDANA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21E15B-MUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21E15B-MUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21E15B-MUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDANA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21G16B-AUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21G16B-AUT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21G16B-AUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA04',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21G16B-MUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21G16B-MUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21G16B-MUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA04',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21J16B-AUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21J16B-AUT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21J16B-AUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='56',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21J16B-MUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21J16B-MUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21J16B-MUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='56',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21E16B-AUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21E16B-AUT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21E16B-AUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDANA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21E16B-MUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21E16B-MUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21E16B-MUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDANA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21E17B-AUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21E17B-AUT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21E17B-AUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDANA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21E17B-MUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21E17B-MUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21E17B-MUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDANA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21E18B-AUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21E18B-AUT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21E18B-AUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDANA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21E18B-MUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21E18B-MUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21E18B-MUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDANA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21G17B-AUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21G17B-AUT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21G17B-AUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA04',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21G17B-MUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21G17B-MUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21G17B-MUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA04',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21G18B-AUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21G18B-AUT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21G18B-AUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA04',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21G18B-MUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21G18B-MUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21G18B-MUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA04',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21J17B-AUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21J17B-AUT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21J17B-AUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='56',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21J17B-MUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21J17B-MUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21J17B-MUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='56',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21J18B-AUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21J18B-AUT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21J18B-AUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='56',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATSAML21J18B-MUT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATSAML21J18B-MUT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.7x4.7mm', 'keywords':'32-bit ARM Cortex-M0+ MCU Microcontroller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/DataSheets/SAM-L21-Family-Data-Sheet-DS60001477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_SAML.kicad_sym\nATSAML21J18B-MUT\n\n32-bit ARM Cortex-M0+ MCU Microcontroller', 'pins':[
            Pin(num='1',name='PA00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB07',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB08',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB09',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA04',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA05',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA06',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA07',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA08',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA09',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA02',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PA16',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA17',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA18',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA19',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA03',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA20',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA21',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA22',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA23',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA24',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA25',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PB22',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB04',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB23',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA27',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VDDCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='56',name='VDDIN',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA30',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA31',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB30',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB05',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB31',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB00',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB01',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB02',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB03',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GNDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDANA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB06',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Interface_HID = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'JoyWarrior24A10L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JoyWarrior24A10L'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'joystick controller 10bit 3-axis', 'description':'', 'datasheet':'http://codemercs.com/downloads/joywarrior/JW_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_HID.kicad_sym\nJoyWarrior24A10L\n\njoystick controller 10bit 3-axis', 'pins':[
            Pin(num='1',name='X0/B0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PullToGnd',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VREG',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='Direct',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='Aux3',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='Aux1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='Dout',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='X1/B1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='Y3/B7',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='Y2/B6',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='Y1/B5',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='Y0/B4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='X2/B2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X3/B3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{CS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Din',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Aux0',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Aux2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SpinWarrior24A3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SpinWarrior24A3'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16bit absolute position USB rotary encoder', 'description':'', 'datasheet':'http://www.codemercs.com/downloads/spinwarrior/SW_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_HID.kicad_sym\nSpinWarrior24A3\n\n16bit absolute position USB rotary encoder', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PullToGND',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Vreg',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='Power',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='Vcc',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{EN}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='In5',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='In3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='In1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='N1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='N0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='In0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='In2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='In4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='N2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SpinWarrior24R4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SpinWarrior24R4'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'8bit relative position USB rotary encoder', 'description':'', 'datasheet':'http://www.codemercs.com/downloads/spinwarrior/SW_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_HID.kicad_sym\nSpinWarrior24R4\n\n8bit relative position USB rotary encoder', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PullToGND',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Vreg',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='Power',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='Vcc',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{EN}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='Sw5',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='Sw3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='Sw1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Sw0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Sw2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Sw4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Sw6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SpinWarrior24R6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SpinWarrior24R6'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'8bit relative position USB rotary encoder', 'description':'', 'datasheet':'http://www.codemercs.com/downloads/spinwarrior/SW_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_HID.kicad_sym\nSpinWarrior24R6\n\n8bit relative position USB rotary encoder', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PullToGND',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Vreg',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='Power',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='Vcc',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{EN}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='Sw1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Sw0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Sw2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='B4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='B5',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JoyWarrior24A8L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JoyWarrior24A8L'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'joystick controller, 8 bit, 4 axis', 'description':'', 'datasheet':'http://codemercs.com/downloads/joywarrior/JW_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_HID.kicad_sym\nJoyWarrior24A8L\n\njoystick controller, 8 bit, 4 axis', 'pins':[
            Pin(num='1',name='X0/B0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PullToGnd',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VREG',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='Direct',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='Aux3',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='Aux1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='Dout',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='X1/B1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='Y3/B7',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='Y2/B6',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='Y1/B5',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='Y0/B4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='X2/B2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X3/B3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{CS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Din',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Aux0',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Aux2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])